@@ -3,20 +3,21 @@
     Example - Basic::
 
         from f5sdk.bigip import ManagementClient
-        from f5sdk.bigip.extension import ExtensionClient
+        from f5sdk.bigip.extension import AS3Client
+
+        mgmt_client = ManagementClient('192.0.2.10', user='admin', password='admin')
+        extension_client = AS3Client(mgmt_client)
 
-        device = ManagementClient('192.0.2.10', user='admin', password='admin')
-        as3 = ExtensionClient(device, 'as3')
         # install AS3 package
         as3.package.install()
 
     Example - Uninstall::
 
-        as3.package.uninstall()
+        extension_client.package.uninstall()
 
     Example - Check if extension component is installed::
 
-        as3.package.is_installed()
+        extension_client.package.is_installed()
 """
 
 from .operation import OperationClient
