@@ -33,13 +33,9 @@ class DeviceReadyError(Exception):
     """ Error raised if device ready check fails """
 
 
-class MethodNotAllowed(Exception):
-    """ Error raised if method is not allowed """
-
-
-class InvalidComponentMethodError(Exception):
-    """ Error raised if invalid component method is invoked """
-
-
 class RetryInterruptedError(Exception):
     """ Error raised if method retry is intentionally interrupted """
+
+
+class InvalidAuthError(Exception):
+    """ Error raised if authentication fails """
